@@ -3,7 +3,7 @@ use warnings;
 package Graphics::Raylib;
 
 # ABSTRACT: Perlish wrapper for Raylib videogame library
-our $VERSION = '0.012'; # VERSION
+our $VERSION = '0.013'; # VERSION
 
 use Carp;
 use Graphics::Raylib::XS qw(:all);
@@ -21,7 +21,7 @@ Graphics::Raylib - Perlish wrapper for Raylib videogame library
 
 =head1 VERSION
 
-version 0.012
+version 0.013
 
 =head1 SYNOPSIS
 
@@ -94,13 +94,15 @@ sub import {
 
 Constructs the Graphics::Raylib window. C<$title> is optional and defaults to C<$0>. Resources allocated for the window are freed when the handle returned by C<window> goes out of scope.
 
+If no graphic device is available it returns an C<undef> value.
+
 =cut
 
 sub window {
     my $class = shift;
 
     my $self = { width => shift, height => shift, title => shift // $0, @_ };
-    InitWindow($self->{width}, $self->{height}, $self->{title});
+    InitWindow($self->{width}, $self->{height}, $self->{title}) or return;
     SetTargetFPS($self->{fps}) if defined $self->{fps};
     ClearBackground($self->{background}) if defined $self->{background};
 
@@ -271,7 +273,7 @@ Ahmad Fatoum C<< <athreef@cpan.org> >>, L<http://a3f.at>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2017 Ahmad Fatoum
+Copyright (C) 2017-2018 Ahmad Fatoum
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
